@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -35,21 +35,18 @@ class Gravatar::GravatarConfigWidgetPrivate
 {
 public:
     GravatarConfigWidgetPrivate()
-        : mEnableGravatarSupport(nullptr)
-        , mConfigureGravatarSetting(nullptr)
     {
     }
 
-    QCheckBox *mEnableGravatarSupport;
-    QPushButton *mConfigureGravatarSetting;
+    QCheckBox *mEnableGravatarSupport = nullptr;
+    QPushButton *mConfigureGravatarSetting = nullptr;
 };
 
 GravatarConfigWidget::GravatarConfigWidget(QWidget *parent)
     : QWidget(parent)
     , d(new Gravatar::GravatarConfigWidgetPrivate)
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout;
-    setLayout(mainLayout);
+    QHBoxLayout *mainLayout = new QHBoxLayout(this);
     mainLayout->setMargin(0);
 
     d->mEnableGravatarSupport = new QCheckBox(i18n("Enable Gravatar Support"));
